/*
 * Copyright 1993, 1995 Christopher Seiwald.
 *
 * This file is part of Jam - see jam.c for Copyright information.
 */

/*
 * command.c - maintain lists of commands
 */

#include "Command.hpp"
#include "Variable.hpp"

namespace Jam
{
	/*
	 * cmd_new() - return a new CMD or 0 if too many args
	 */

	Command* Command::CreateInstance(
		RULE	*rule,
		List	*targets,
		List	*sources,
		List	*shell )
	{
		Command* pInstance = new Command;

		pInstance->rule = rule;
		pInstance->shell = shell;
		pInstance->next = 0;

		lol_init( &pInstance->args );
		lol_add( &pInstance->args, targets );
		lol_add( &pInstance->args, sources );

		/* Bail if the result won't fit in MAXLINE */
		/* We don't free targets/sources/shell if bailing. */

		if( var_string( rule->actions, pInstance->buf, MAXLINE, &pInstance->args ) < 0 )
		{
			delete pInstance;
			return 0;
		}

		return pInstance;
	}

	/*
	 * cmd_free() - free a CMD
	 */

	void Command::DeleteInstance(Command* pInstance)
	{
		lol_free( &pInstance->args );
		List::list_free( pInstance->shell );
		delete pInstance;
	}

	Command* Command::GetNext(void) const
	{
		return this->next;
	}
}